@@ -4,9 +4,10 @@
 #include <stddef.h>
 #include <sepol/context_record.h>
 #include <sepol/handle.h>
-#include <sys/cdefs.h>
 
-__BEGIN_DECLS
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 struct sepol_node;
 struct sepol_node_key;
@@ -92,5 +93,8 @@ extern int sepol_node_clone(sepol_handle_t * handle,
 
 extern void sepol_node_free(sepol_node_t * node);
 
-__END_DECLS
+#ifdef __cplusplus
+}
+#endif
+
 #endif
